import { Component, OnInit, AfterViewInit, HostListener } from "@angular/core";
import { ToolService } from 'src/app/services/tool.service';
import { MainService } from 'src/app/services/main.service';
import { ActivatedRoute } from '@angular/router';

@Component({
  selector: "app-washing-batch-view",
  templateUrl: "./washing-batch-view.component.html",
  styleUrls: ["./washing-batch-view.component.less"],
})
export class WashingBatchViewComponent implements OnInit, AfterViewInit {
  constructor(
    public tool: ToolService,
    private mainService: MainService,
    private route: ActivatedRoute,
  ){}

  ngOnInit() {
    this.hosId = this.tool.getCurrentHospital().id;
    this.getParentList();
    this.getChildList();
    this.getList();
  }

  ngAfterViewInit(){
    this.resizeInit();
  }
  _timer = null;
  @HostListener('window:resize')
  resizeInit(){
    clearTimeout(this._timer);
    this._timer = setTimeout(() => {
      this.scrollY = window.innerHeight - 206 - document.querySelector('.head').clientHeight - document.querySelector('th').clientHeight;
    }, 500)
  }

  listOfData: any[] = []; //表格数据
  loading:boolean = false;
  isAllDisplayDataChecked = false; //当前页是否全选
  mapOfCheckedId: { [key: string]: boolean } = {};
  checkedDepIds = []; //已选中单列id
  scrollY:number = 0;
  hosId:any;
  searchDto:any = {
    parent: null,
  }
  parentList: Array<any> = []; //父级分类数据字典信息
  childList: Array<any> = []; //分类数据字典信息
  rows:any[] = [];
  totalData:any = {};

  // 全选
  checkAll(value: boolean): void {
    this.listOfData.forEach((item) => {
      this.mapOfCheckedId[item[0]] = value;
    });
    this.refreshStatus();
  }

  // 单选
  refreshStatus(): void {
    this.isAllDisplayDataChecked = this.listOfData.every(
      (item) => this.mapOfCheckedId[item[0]]
    );
    let arr = [];
    for (var k in this.mapOfCheckedId) {
      if (this.mapOfCheckedId[k]) {
        arr.push(Number(k));
      }
    }
    this.checkedDepIds = arr;
  }

  // 整行操作
  selectedListData(data) {
    this.mapOfCheckedId[data[0]] = !this.mapOfCheckedId[data[0]];
    this.refreshStatus();
  }

  // 获取父级分类
  getParentList() {
    let postData = {
      idx: 0,
      sum: 9999,
      dictionaryTree: {
        hosId: this.hosId,
        level: 1,
        key: 'clothes_type',
        deleted: 0,
      },
    };
    this.mainService
      .getFetchDataList("simple/data", "dictionaryTree", postData)
      .subscribe((result) => {
        if(result.status == 200){
          this.parentList = result.list || [];
        }
      });
  }

  // 获取分类
  getChildList() {
    let postData = {
      idx: 0,
      sum: 9999,
      dictionaryTree: {
        hosId: this.hosId,
        level: 2,
        key: 'clothes_type',
        deleted: 0,
      },
    };
    this.mainService
      .getFetchDataList("simple/data", "dictionaryTree", postData)
      .subscribe((result) => {
        if(result.status == 200){
          this.childList = result.list || [];
        }
      });
  }

  //批量送回
  loading3 = false;
  delModal: boolean = false; //模态框
  content:string = '';
  showDelModal() {
    this.delModal = true;
    this.content = `您选择了${this.checkedDepIds.length}个科室批量送回被服，您确认吗？`;
  }
  hideDelModal() {
    this.delModal = false;
  }
  confirmDel() {
    this.loading3 = true;
    let postData: any = {
      hosId: this.hosId,
      batchId: this.route.snapshot.paramMap.get("id"),
      deptIds: this.checkedDepIds.toString(),
    };
    this.mainService.clothesWashing(postData, 'batchBack').subscribe((data) => {
      this.loading3 = false;
      this.delModal = false;
      if (data.status == 200) {
        this.showPromptModal("操作", true, "");
      } else {
        this.showPromptModal("操作", false, data.msg);
      }
    });
  }

  // 展示信息提示框（con:提示信息，success:操作是否成功，promptInfo:操作结果提示信息）
  promptContent: string; //操作提示框提示信息
  ifSuccess: boolean; //操作成功/失败
  promptInfo: string; //操作结果提示信息
  promptModalShow: boolean; //操作提示框是否展示
  showPromptModal(con, success, promptInfo?) {
    this.promptModalShow = false;
    this.promptContent = con;
    this.ifSuccess = success;
    this.promptInfo = promptInfo;
    setTimeout(() => {
      this.promptModalShow = true;
    }, 100);
    this.getList();
  }

  // 表格数据
  getList() {
    let postData: any = {
      hosId: this.hosId,
      batchId: this.route.snapshot.paramMap.get("id"),
      clothesTypeParent: undefined,
      clothesType: undefined,
    };
    this.loading = true;
    this.mainService
      .clothesWashing(postData, 'view')
      .subscribe((result) => {
        this.loading = false;
        if(result.status == 200){
          let rows = result.head || [];
          this.rows = ['', ...rows.map(v => v.name), '','件数', '费用/元'];
          let listOfData_res = result.data || [];
          this.listOfData = listOfData_res.map(v => ([
            v.id,
            v.dept,
            ...v.clothesWashingDTOS.map(vv => vv.sendBackNum),
            '',
            v.nums,
            v.price,
          ]))
          this.totalData = result.totalData || {};
        }
      });
  }
}

